<?PHP

include("panic.inc.php"); // Nice error function

/*

  @author Nicholas Avenell <nicholas@aquarionics.com>
  @desc   Screenpop Test - XML Parse

  2. An XML feed exists here:
    http://pricefeeds.williamhill.com/oxipubserver?action=template&template=getHierarchyByMarketType&classId=1&marketSort=MR&filterBIR=N
    
    Create a function that extracts all fixtures and full time odds for
    the English Premier League from the above feed. The function should
    return an array where each element contains a fixture so to speak,
    meaning home team, away team, odds for a home win, odds for an away
    win, and odds for a draw. Your function should handle error situations
    gracefully. Please deliver your function such that it can be easily
    tested with the array data presented visually.

*/

$url = "http://pricefeeds.williamhill.com/oxipubserver?action=template&template=getHierarchyByMarketType&classId=1&marketSort=MR&filterBIR=N";

#$url = "bad_data.xml"; // Known valid XML that isn't right
#$url = "testdata.xml"; // Known correct XML
#$url = "http://localhost"; // a random HTML page.

define("PREMIER_LEAGUE", 295); // William Hill's ID for the Premier League

function get_simplexml_handler($url){
  libxml_use_internal_errors(true);
  $sxe = simplexml_load_file($url);
  if (!$sxe) {
      $data = "Failed loading XML\n";
      $errors = 0;
      $furtherinfo = "";
      foreach(libxml_get_errors() as $error) {
           error_log("XML Error ".$error->message);
           $errors++;
           $furtherinfo .= $error->message."<br/>";
      }
      $e = new Exception("$errors Errors loading XML");
      $e->furtherInfo = $furtherinfo;
  }
  return $sxe; 
}


function get_league(&$sxe, $id){
  
  if(!isset($sxe->response->williamhill->class->type)){
     throw new Exception("Unable to load required data");
  }
  
  foreach($sxe->response->williamhill->class->type as $league){  
    if($league['id'] == $id){
      return $league;
      break;
    }
  }
}

function parse_fixtures($url, $league_id, $full_time_only = true){

  $sxe    = get_simplexml_handler($url);
  $league = get_league($sxe, 295);
  $fixtures = array();
  
  if(!$league){
     throw new Exception("Unable to load required league data");
  }
  
  if(!isset($league->market)){
     throw new Exception("Unable to load required fixture data");
  }
  
  foreach($league->market as $fixture){
    // A bit of a hack. The spec says "full time odds", but the feed provides a lot of uselessium 
    // in the form of "15 minute" bets and so on. Wittling this down to full time isn't apparently 
    // easy using XML on its own, so I'm doing a string search. In the Real World, we'd look for 
    // clarification, see if there's a better data call since we're dumping a lot of data here.
    
    if($full_time_only && !stristr($fixture['name'], "90 Minutes")){
      continue;
    }
    
    $home = $fixture->participant[0];
    $draw = $fixture->participant[1];
    $away = $fixture->participant[2];
    
      $fixtures[] = array(
        'home_team' => (string)$home['name'],
        'away_team' => (string)$away['name'],
        'home_odds' => (string)$home['odds'],
        'away_odds' => (string)$away['odds'],
        'draw_odds' => (string)$draw['odds'],
    );
    
  }
  
  return $fixtures;
}

$fixtures = parse_fixtures($url, PREMIER_LEAGUE);

echo "<table border=1 width=\"50%\">\n";

foreach($fixtures as $fixture){
echo "<tr><th colspan=\"3\">".$fixture['home_team']." v ".$fixture['away_team']."</th></tr>";
echo "<tr><th>Home Win</th><th>Draw</th><th>Away Win</th></tr>";
echo "<tr>";
  echo "<td>".$fixture['home_odds']."</td>";
  echo "<td>".$fixture['draw_odds']."</td>";
  echo "<td>".$fixture['away_odds']."</td>";
echo "</tr>";
  
}

